/* Copyright (c) 2002-2012 Pigeonhole authors, see the included COPYING file 
 */

#ifndef __SIEVE_CONFIG_H
#define __SIEVE_CONFIG_H

#include "pigeonhole-config.h"

#define SIEVE_IMPLEMENTATION PIGEONHOLE_NAME " Sieve " PIGEONHOLE_VERSION

#define SIEVE_SCRIPT_FILEEXT "sieve"
#define SIEVE_BINARY_FILEEXT "svbin"

#endif
